==> MicroSweeper-1.0.13.tar.bz2: ParticipantSelector.java <==
/*
 * Copyright 2009, Petr Machata
 *
 * This file is part of MicroSweeper.
 *
 * MicroSweeper is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * MicroSweeper is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MicroSweeper.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * ParticipantSelector takes care of figuring out which fields on the
 * board should one add together to get the number of mines "around"
 * each field.  Most common participant selector just counts mines on
 * all neighboring fields.  Participant indices then map naturally to
 * neighbor directions.
 */
public class ParticipantSelector {
    // Maximum number of participants each field has.
    public byte getCountParticipantIndices(MineField mf) {
	return mf.getCountNeighborIndices();
    }

    // Answer participant parIdx for field fieldIdx, or -1 if that
    // participant is unavailable (off-board, invisible, or otherwise
    // unavailable for given field).
    public byte getParticipant(MineField mf, byte fieldIdx, byte parIdx) {
	return mf.getNeighbor(fieldIdx, parIdx);
    }

    // Just a wrapper around the above.
    public Field getParticipant(MineField mf, Field f, byte parIdx)
    //throws IllegalArgumentException // if participant index is invalid
    {
	byte idx2 = getParticipant(mf, f.index, parIdx);
	if (idx2 < 0)
	    return null;
	else
	    return mf.getField(idx2);
    }

    public byte moveNTimes(MineField mf, byte fieldIdx, byte parIdx, int times) {
	while (times-- > 0) {
	    if (fieldIdx == -1)
		break;
	    else
		fieldIdx = mf.getNeighbor(fieldIdx, parIdx);
	}
	return fieldIdx;
    }
}

==> MicroSweeper-1.0.15.tar.bz2: ParticipantSelector.java <==
/*
 * Copyright 2009,2010, Petr Machata
 *
 * This file is part of MicroSweeper.
 *
 * MicroSweeper is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * MicroSweeper is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MicroSweeper.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * ParticipantSelector takes care of figuring out which fields on the
 * board should one add together to get the number of mines "around"
 * each field.  Most common participant selector just counts mines on
 * all neighboring fields.  Participant indices then map naturally to
 * neighbor directions.
 */
public abstract class ParticipantSelector {
    // Maximum number of participants each field has.
    public byte getCountParticipantIndices(MineField mf) {
	return mf.getCountNeighborIndices();
    }

    // Answer participant parIdx for field fieldIdx, or -1 if that
    // participant is unavailable (off-board, invisible, or otherwise
    // unavailable for given field).
    public byte getParticipant(MineField mf, byte fieldIdx, byte parIdx) {
	if (fieldIdx < 0)
	    return -1;
	return mf.getNeighbor(fieldIdx, parIdx);
    }

    // Just a wrapper around the above.
    public Field getParticipant(MineField mf, Field f, byte parIdx)
    {
	byte idx2 = getParticipant(mf, f.fieldIdx, parIdx);
	if (idx2 < 0)
	    return null;
	else
	    return mf.getField(idx2);
    }

    public byte moveNTimes(MineField mf, byte fieldIdx, byte parIdx, int times) {
	while (times-- > 0) {
	    if (fieldIdx == -1)
		break;
	    else
		fieldIdx = mf.getNeighbor(fieldIdx, parIdx);
	}
	return fieldIdx;
    }

    public abstract int howManyMines(int level, int endLevel);
}
